#!/usr/bin/perl
#
# tunectl.cgi
#
# display/edit tunebot global controls.
#

########################################################################
# perl script boilerplate.
# set tunebot root and load utility module.
#
BEGIN {
    $tunebot_root="XXX-the-tunebot-install-root";
    @INC=($tunebot_root."/lib", @INC);
}
use Tunebot;
#
# end of perl boilerplate
########################################################################

## setcontrol(name, value)
#
# rewrite the given line in the controls file, or add it if it didn't exist.
#
sub setcontrol {
    my $n=$_[0];
    my $v=$_[1];
    my @c=();
    my $line;
    my $unf=1;
    open(I, $controls);
    while ($line = <I>) {
	chomp $line;
	if ($line =~ /^$n=/) {
	    @c=(@c, "$n=$v");
	    $unf=0;
	} else {
	    @c=(@c, $line);
	}
    }
    close(I);
    if ($unf) {
	@c=(@c, "$n=$v");
    }
    open(O, ">$controls");
    foreach $line (@c) {
	print O "$line\n";
    }
    close(O);
}

$cgibinurl=$configs{"CGI_BIN_URL"};
$topurl=$configs{"HTML_TOP_URL"};

$controls=$configs{"CONTROLS"};

Tunebot::suckInCookies;
$tunebot_user=$cookie{TUNEBOTUSER};

Tunebot::suckInPostGet;

Tunebot::printPageHeader "Control Panel";

#
# this is the list of controls that can be modified, in order:
#  - variable name
#  - description
#  - display format (INT or BOOL or a printf string)
#  - list of lists of choices to display and parameter values.
#  - scope of variable: 'g' is global, 'i' is individual - can have either
#    or both.
#
@ctrls = (
    {
	name => "RANDOM_IF_IDLE",
	desc => "Play random tunes when no requests (no dead air)",
	scope => "g",
	fmt => "BOOL",
	choices => [
	    [ "Yes", "1" ],
	    [ "No", "0" ],
	]
    },
    {
	name => "RANDOM_FROM_Q",
	desc => "Play requests in random order",
	scope => "g",
	fmt => "BOOL",
	choices => [
	    [ "Yes", "1" ],
	    [ "No", "0" ],
	]
    },
    {
	name => "PREEMPT_Q_PERC",
	"desc" => "Probability of playing a random tune before a request",
	scope => "g",
	fmt => "%s%%",
	choices => [
	    [ "50%", "50" ],
	    [ "30%", "30" ],
	    [ "20%", "20" ],
	    [ "10%", "10" ],
	    [ "0%", "0" ],
	]
    },
    {
	name => "FILLET_TIME",
	desc => "Announce time and play fillet after some minutes",
	scope => "g",
	fmt => "INT",
	choices => [
	    [ "30", "30" ],
	    [ "45", "45" ],
	    [ "60", "60" ],
	    [ "90", "90" ],
	    [ "120", "120" ],
	    [ "don't", "0" ],
	]
    },
    {
	name => "HOWMANY_TUNES",
	desc => "Default number of tunes to show in Whuzzon",
	scope => "gi",
	fmt => "INT",
	choices => [
	    [ "50", "50" ],
	    [ "20", "20" ],
	    [ "10", "10" ],
	    [ "5", "5" ],
	    [ "2", "2" ],
	    [ "1", "1" ],
	]
    },
    {
	name => "RELOAD_WHUZZON",
	desc => "Auto-reload Whuzzon page every minute",
	scope => "gi",
	fmt => "BOOL",
	choices => [
	    [ "Yes", "60" ],
	    [ "No", "0" ],
	]
    },
    {
	name => "NOW_PLAYING_COVER",
	desc => "Show album cover in Whuzzon",
	scope => "gi",
	fmt => "BOOL",
	choices => [
	    [ "Yes", "1" ],
	    [ "No", "0" ],
	]
    },
    {
	name => "PUT_BACK_INDEX",
	desc => "Jump back to index after taking request (else go to Whuzzon)",
	scope => "gi",
	fmt => "BOOL",
	choices => [
	    [ "Yes", "1" ],
	    [ "No", "0" ],
	]
    },
    {
	name => "INDEX_ALBUMS",
	desc => "Number of albums to show per index page",
	scope => "gi",
	fmt => "INT",
	choices => [
	    [ "100", "100" ],
	    [ "50", "50" ],
	    [ "20", "20" ],
	    [ "10", "10" ],
	    [ "5", "5" ],
	    [ "2", "2" ],
	    [ "1", "1" ],
	]
    },
    {
	name => "AVOID_ANCHORS",
	desc => "Avoid use of page anchors (which break some browsers)",
	scope => "gi",
	fmt => "BOOL",
	choices => [
	    [ "Yes", "1" ],
	    [ "No", "0" ],
	]
    },
    {
	name => "MYSTERY_PARAM",
	desc => "Some mystery parameter",
	scope => "g",
	fmt => "BOOL",
	choices => [
	    [ "Yes", "1" ],
	    [ "No", "0" ],
	]
    },
);

#
# turn the controls list into a hash so we can check names
#
foreach $x (@ctrls) {
    $ctrl{$x->{name}}=$x;
}

#
# start displaying the page
#
print "<center>\n";
print "<font size=+2><b>Control Panel</b></font>\n";
print "<br>Tunebot version ".$configs{TUNEBOT_VERSION}."\n";
print "</center>\n";

#
# set control if we got a posted name and new value
#
if ($posts{name} ne "" && $posts{val} ne "") {
    if ($ctrl{$posts{name}} ne "") {
#	print "Setting control $posts{name} to $posts{val}\n";
	$configs{$posts{name}} = $posts{val};
	setcontrol($posts{name}, $posts{val});
    } else {
#	print "Not setting bogus control $posts{name}\n";
	print "Unable to set control <em>$posts{name}</em>, sorry.\n";
    }
}

#
# render table of current (new) parameter values
#
print "<p>\n";
print "<table width=85% align=center>\n";
print "<tr><th align=left>Control</th><th>Value</th><th>Modify</th></tr>\n";
print "<tr><td colspan=3><hr></td></tr>\n";

foreach $x (@ctrls) {
    print "<tr><td>".$x->{desc}."</td>\n";
    $fmt=$x->{fmt};
    print " <td align=center>";
#    $configs{$x->{name}};
    if ($configs{$x->{name}} eq "") {
	$configs{$x->{name}} = "0";
    }
    if ($fmt eq "INT") {
	print $configs{$x->{name}};
    } elsif ($fmt eq "BOOL") {
	if ($configs{$x->{name}} != 0) {
	    print "Yes";
	} else {
	    print "No";
	}
    } else {
	printf $x->{fmt}, $configs{$x->{name}};
    }
    print "</td>\n";
    print " <td align=center>\n";
    $j="";
    foreach $c (@{$x->{choices}}) {
	print "  $j<a href=\"$cgibinurl/tunectl.cgi?name=".$x->{name}."&val=".$c->[1]."\">".$c->[0]."</a>\n";
	$j=" : ";
    }
    print " </td>\n";
    print "</tr>\n";
}


print "<tr><td colspan=3><hr></td></tr>\n";
print "</table>\n";

Tunebot::printPageTrailer;
exit 0

